@@ -1,5 +1,6 @@
 from pydantic import BaseModel
 from typing import Any, Dict, List, Optional
+from enum import Enum
 import functools
 
 
@@ -9,18 +10,27 @@ class NoteConfig(BaseModel):
     header: Optional[List[str]]
 
 
+class FileType(Enum):
+    csv = "csv"
+    excel = "excel"
+    pickle = "pickle"
+
+
 class Result(BaseModel):
-    note: Dict[str, Any]
+    persistent: Optional[Dict[FileType, Dict[str, Any]]]
+    result: Optional[Dict[FileType, Dict[str, Any]]]
+    note: Optional[Dict[str, Any]]
 
 
 class Note:
     filepath: Optional[str] = None
     header: Optional[List[str]] = None
-    encoding: str="utf-8"
+    encoding: str = "utf-8"
 
     @classmethod
     def __check_file(cls):
         from os.path import exists
+
         if not exists(cls.filepath):
             return False
         return True
@@ -35,12 +45,16 @@ class Note:
         return True
 
     @classmethod
-    def set_config(cls, note_config:NoteConfig):
+    def set_config(cls, note_config: NoteConfig):
         from os.path import join
         from os import getcwd
         from datetime import datetime
+
         if note_config.filename_prefix and note_config.directory_name:
-            file_name = "_".join(note_config.filename_prefix + [datetime.strftime(datetime.now(), "%Y%m%d%H%M%S") + ".csv",])
+            file_name = "_".join(
+                note_config.filename_prefix
+                + [datetime.strftime(datetime.now(), "%Y%m%d%H%M%S") + ".csv",]
+            )
             cls.filepath = join(getcwd(), note_config.directory_name, file_name)
             cls.header = note_config.header
             if (not cls.__check_file()) or (not cls.__check_header()):
@@ -53,22 +67,26 @@ class Note:
             fa.write(line)
 
     @classmethod
-    def record(cls, note_config:NoteConfig):
+    def record(cls, note_config: NoteConfig):
         cls.set_config(note_config)
+
         def wrapper(func):
             @functools.wraps(func)
             def inner(*args, **kwargs):
-                result:Result = func(*args, **kwargs)
+                result: Result = func(*args, **kwargs)
                 line = []
                 for column_name in cls.header:
                     line.append(str(result.note[column_name]))
                 line = ",".join(line) + "\n"
                 cls.record_line(line=line)
+
             @functools.wraps(func)
             def inner_empty(*args, **kwargs):
                 return func(*args, **kwargs)
+
             if cls.filepath != None and cls.header != None:
                 return inner
             else:
                 return inner_empty
+
         return wrapper
